<?php
/**
 * Call to Action options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'yule_pro_cta_section', array(
	'title'             => esc_html__( 'Call to Action','yule-pro' ),
	'description'       => esc_html__( 'Call to Action options.', 'yule-pro' ),
	'panel'             => 'yule_pro_front_page_panel',
) );

// cta enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[cta_section_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['cta_section_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'Call to Action Enable', 'yule-pro' ),
	'section'           => 'yule_pro_cta_section',
	'on_off_label' 		=> yule_pro_switch_options(),
) ) );

// cta content type control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'yule_pro_sanitize_select',
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yule-pro' ),
	'section'           => 'yule_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'yule_pro_is_cta_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'yule-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'yule-pro' ),
		'page' 		=> esc_html__( 'Page', 'yule-pro' ),
		'post' 		=> esc_html__( 'Post', 'yule-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'yule_pro_sanitize_page'
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'yule-pro' ),
	'section'        	=> 'yule_pro_cta_section',
	'active_callback' 	=> 'yule_pro_is_cta_section_content_page',
	'type'				=> 'dropdown-pages'
) );

// cta section content type post setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[cta_content_post]', array(
	'validate_callback' => 'yule_pro_validate_post_id',
	'sanitize_callback' => 'yule_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_content_post]', array(
	'active_callback'	=> 'yule_pro_is_cta_section_content_post',
	'label'             => esc_html__( 'Input Post Id', 'yule-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'yule-pro' ),
	'section'           => 'yule_pro_cta_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// cta title setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['cta_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'yule-pro' ),
	'section'        	=> 'yule_pro_cta_section',
	'active_callback' 	=> 'yule_pro_is_cta_section_content_custom',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[cta_title]', array(
		'selector'            => '#call-to-action .section-header h2.section-title',
		'settings'            => 'yule_pro_theme_options[cta_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_cta_title_partial',
    ) );
}

// cta description setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[cta_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['cta_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_description]', array(
	'label'           	=> esc_html__( 'Description', 'yule-pro' ),
	'section'        	=> 'yule_pro_cta_section',
	'active_callback' 	=> 'yule_pro_is_cta_section_content_custom',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[cta_description]', array(
		'selector'            => '#call-to-action .section-content',
		'settings'            => 'yule_pro_theme_options[cta_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_cta_description_partial',
    ) );
}

// author additional image setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[cta_image]', array(
	'sanitize_callback' => 'yule_pro_sanitize_image',
	'default'          	=> $options['cta_image'],
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yule_pro_theme_options[cta_image]',
		array(
		'label'       		=> esc_html__( 'Select Image', 'yule-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yule-pro' ), 580, 600 ),
		'section'     		=> 'yule_pro_cta_section',
		'active_callback'	=> 'yule_pro_is_cta_section_content_custom',
) ) );

// cta btn label setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[cta_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'yule-pro' ),
	'section'        	=> 'yule_pro_cta_section',
	'active_callback' 	=> 'yule_pro_is_cta_section_content_custom',
	'type'				=> 'url',
) );

// cta btn label setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[cta_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['cta_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[cta_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'yule-pro' ),
	'section'        	=> 'yule_pro_cta_section',
	'active_callback' 	=> 'yule_pro_is_cta_section_content_not_demo',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[cta_btn_label]', array(
		'selector'            => '#call-to-action .more-link a.btn-default',
		'settings'            => 'yule_pro_theme_options[cta_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_cta_btn_label_partial',
    ) );
}
