<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function yule_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'yule_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function yule_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'yule-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'yule-pro' ),
            'header-font-2'   => esc_html__( 'Exo', 'yule-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'yule-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'yule-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'yule-pro' ),
        );

        $output = apply_filters( 'yule_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'yule_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function yule_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'yule-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'yule-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'yule-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'yule-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'yule-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'yule-pro' ),
        );

        $output = apply_filters( 'yule_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;

if ( ! function_exists( 'yule_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function yule_pro_site_layout() {
        $yule_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'yule_pro_site_layout', $yule_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'yule_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function yule_pro_sidebar_position() {
        $yule_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'    => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'yule_pro_sidebar_position', $yule_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'yule_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function yule_pro_selected_sidebar() {
        $yule_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'yule-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'yule-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'yule-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'yule-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'yule-pro' ),
        );

        $output = apply_filters( 'yule_pro_selected_sidebar', $yule_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'yule_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function yule_pro_pagination_options() {
        $yule_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'yule-pro' ),
            'infinite'  => esc_html__( 'Infinite Scroll', 'yule-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'yule-pro' ),
        );

        $output = apply_filters( 'yule_pro_pagination_options', $yule_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'yule_pro_get_archive_col' ) ) :
    /**
     * List of column options.
     * @return array List of all column options.
     */
    function yule_pro_get_archive_col() {
        $arr = array(
            'col-1' => esc_html__( 'One Column', 'yule-pro' ),
            'col-2' => esc_html__( 'Two Column', 'yule-pro' ),
            'col-3' => esc_html__( 'Three Column', 'yule-pro' ),
        );
        return apply_filters( 'yule_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'yule_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function yule_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'yule-pro' ),
            'off'       => esc_html__( 'Disable', 'yule-pro' )
        );
        return apply_filters( 'yule_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'yule_pro_popular_options' ) ) :
    /**
     * List of popular options
     * @return array List of popular options.
     */
    function yule_pro_popular_options() {
        $arr = array(
            'demo'      => esc_html__( 'Demo', 'yule-pro' ),
            'page'      => esc_html__( 'Page', 'yule-pro' ),
            'post'      => esc_html__( 'Post', 'yule-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, array( 'product' => esc_html__( 'Product', 'yule-pro' ) ) );
        }

        return apply_filters( 'yule_pro_popular_options', $arr );
    }
endif;

if ( ! function_exists( 'yule_pro_latest_options' ) ) :
    /**
     * List of latest options
     * @return array List of latest options.
     */
    function yule_pro_latest_options() {
        $arr = array(
            'demo'          => esc_html__( 'Demo', 'yule-pro' ),
            'post'          => esc_html__( 'Post', 'yule-pro' ),
            'category'      => esc_html__( 'Post Category', 'yule-pro' ),
            'latest-post'   => esc_html__( 'Latest Posts', 'yule-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, 
                array( 
                    'product'           => esc_html__( 'Product', 'yule-pro' ), 
                    'product-category'  => esc_html__( 'Product Category', 'yule-pro' ), 
                    'latest-product'    => esc_html__( 'Latest Products', 'yule-pro' ), 
                    ) 
                );
        }

        return apply_filters( 'yule_pro_latest_options', $arr );
    }
endif;

if ( ! function_exists( 'yule_pro_featured_options' ) ) :
    /**
     * List of featured options
     * @return array List of featured options.
     */
    function yule_pro_featured_options() {
        $arr = array(
            'demo'      => esc_html__( 'Demo', 'yule-pro' ),
            'page'      => esc_html__( 'Page', 'yule-pro' ),
            'post'      => esc_html__( 'Post', 'yule-pro' ),
        );
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, array( 'product' => esc_html__( 'Product', 'yule-pro' ) ) );
        }

        return apply_filters( 'yule_pro_featured_options', $arr );
    }
endif;