<?php
/**
 * Latest section
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */
if ( ! function_exists( 'yule_pro_add_latest_section' ) ) :
    /**
    * Add latest section
    *
    *@since Yule Pro 1.0.0
    */
    function yule_pro_add_latest_section() {
    	$options = yule_pro_get_theme_options();
        // Check if latest is enabled on frontpage
        $latest_enable = apply_filters( 'yule_pro_section_status', true, 'latest_section_enable' );

        if ( true !== $latest_enable ) {
            return false;
        }
        // Get latest section details
        $section_details = array();
        $section_details = apply_filters( 'yule_pro_filter_latest_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest section now.
        yule_pro_render_latest_section( $section_details );
    }
endif;
add_action( 'yule_pro_primary_content', 'yule_pro_add_latest_section', 20 );

if ( ! function_exists( 'yule_pro_get_latest_section_details' ) ) :
    /**
    * latest section details.
    *
    * @since Yule Pro 1.0.0
    * @param array $input latest section details.
    */
    function yule_pro_get_latest_section_details( $input ) {
        $options = yule_pro_get_theme_options();

        // Content type.
        $latest_content_type  = $options['latest_content_type'];
        $latest_count = ! empty( $options['latest_count'] ) ? $options['latest_count'] : 6;
        $content = array();
        switch ( $latest_content_type ) {
            case 'demo':
                $title = array(
                    1 => esc_html__( 'Christmas Bag', 'yule-pro' ),
                    2 => esc_html__( 'Christmas Accessories', 'yule-pro' ),
                    3 => esc_html__( 'Christmas Souvenir', 'yule-pro' ),
                    4 => esc_html__( 'Christmas Wear', 'yule-pro' ),
                    5 => esc_html__( 'Christmas Sweets', 'yule-pro' ),
                    6 => esc_html__( 'Christmas Cards', 'yule-pro' ),
                    );
                for ( $i = 1; $i <= 6; $i++ ) :
                    $demo['title']      = $title[$i];
                    $demo['price']		= sprintf( esc_html__( '%1$s150%2$s', 'yule-pro' ), '$<ins>', '</ins>' );
                    $demo['image']		= get_template_directory_uri() . '/assets/uploads/product-0' . $i . '.jpg';
                    $demo['url']		= '#';
                    $demo['rating'] = sprintf( esc_html__( '%1$sRated %2$s4.00 %3$s out of 5 %4$s', 'yule-pro' ), '<div class="star-rating"><span style="width:80%">', '<strong class="rating">', '</strong>', '</span></div>' );

                    // Push to the main array.
                    array_push( $content, $demo );
                endfor;
            break;

            case 'post':
                $post_ids = ! empty( $options['latest_content_post'] ) ? $options['latest_content_post'] : array();

                if ( empty( $post_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => count( $post_ids ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'latest-post':
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => $latest_count,
                    'ignore_sticky_posts'   => true,
                    );
            break;

             case 'latest-product':
                $args = array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $latest_count,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'product':
                $post_ids = ! empty( $options['latest_content_product'] ) ? $options['latest_content_product'] : array();

                if ( empty( $post_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => count( $post_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'category':
                $cat_id = ! empty( $options['latest_content_category'] ) ? $options['latest_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => absint( $latest_count ),
                    );
            break;

            case 'product-category':
                $cat_id = ! empty( $options['latest_content_product_category'] ) ? $options['latest_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $latest_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }

        if ( $latest_content_type !== 'demo' ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']     	= get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']   	= get_the_permalink();
                    $page_post['image']		= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-400x400.jpg';
                    if ( class_exists( 'WooCommerce' ) && in_array( $latest_content_type, array( 'product', 'product-category', 'latest-product' ) ) ):
                    	$product = new WC_Product( get_the_id() );
                        $page_post['price'] = $product->get_price_html();
                    	$page_post['rating'] = wc_get_rating_html( $product->get_average_rating() );
                	endif;

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest section content details.
add_filter( 'yule_pro_filter_latest_section_details', 'yule_pro_get_latest_section_details' );


if ( ! function_exists( 'yule_pro_render_latest_section' ) ) :
  /**
   * Start latest section
   *
   * @return string latest content
   * @since Yule Pro 1.0.0
   *
   */
   function yule_pro_render_latest_section( $content_details = array() ) {
        $options = yule_pro_get_theme_options();
        $latest_content_type  = $options['latest_content_type'];
        $title = ! empty( $options['latest_title'] ) ? $options['latest_title'] : esc_html__( 'Latest Products', 'yule-pro' );
        $btn_label = ! empty( $options['latest_btn_label'] ) ? $options['latest_btn_label'] : esc_html__( 'View All Products', 'yule-pro' );
        if ( class_exists( 'WooCommerce' ) && in_array( $latest_content_type , array( 'product', 'latest-product', 'product-category' ) ) ) :
            $btn_link = get_option( 'woocommerce_shop_page_id' );
            if ( ! empty( $btn_link ) )
                $btn_link = get_the_permalink( $btn_link );
            else
                $btn_link = '';

        elseif ( in_array( $latest_content_type , array( 'post', 'latest-post' ) ) ) :
            $btn_link = get_option( 'page_for_posts' );

            if ( ! empty( $btn_link ) )
                $btn_link = get_the_permalink( $btn_link );
            else
                $btn_link = '';
        elseif ( 'category' == $latest_content_type ) :
            $cat_id = ! empty( $options['latest_content_category'] ) ? $options['latest_content_category'] : '';
            $btn_link = ! empty( $cat_id ) ? get_category_link( $cat_id ) : '#';
        else :
            $btn_link = '#';
        endif;

        if ( empty( $content_details ) ) {
            return;
        } ?>
    	<div id="latest-products" class="relative page-section">
            <div class="wrapper">
                <div class="section-header clear">
                    <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
                    <?php if ( ! empty( $btn_link ) ) : ?>
                        <div class="more-link">
                            <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-default"><?php echo esc_html( $btn_label ); ?></a>
                        </div>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content">
                    <ul class="products col-3">
                        <?php foreach ( $content_details as $content ) : ?>
                            <li>
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                    <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    <?php if ( ! in_array( $latest_content_type, array( 'post', 'category', 'latest-post' ) ) ) : ?>
                                        <?php echo wp_kses_post( $content['rating'] ); ?>
                                        <span class="price">
                                            <?php echo wp_kses_post( $content['price'] ); ?>
                                        </span>
                                    <?php endif; ?>
                                </a>

                                <?php if ( class_exists( 'WooCommerce' ) && in_array( $latest_content_type, array( 'product', 'product-category', 'latest-product' ) ) ) : ?>
                                    <a rel="nofollow" href="<?php echo do_shortcode( '[add_to_cart_url id="' . absint( $content['id'] ) . '"]' ); ?>" data-quantity="1" data-product_id="<?php echo absint( $content['id'] ) ?>" data-product_sku="" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php esc_html_e( 'Add to cart', 'yule-pro' ); ?></a>
                                <?php elseif ( 'demo' == $latest_content_type ) : ?>
                                    <a href="#" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php esc_html_e( 'Add to cart', 'yule-pro' ); ?></a>
                                <?php endif; ?>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div><!-- .section-content -->

                <?php if ( ! empty( $btn_link ) ) : ?>
                    <div class="more-link">
                        <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-default"><?php echo esc_html( $btn_label ); ?></a>
                    </div>
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #latest-products -->
    <?php
    }
endif;