<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

if ( ! function_exists( 'yule_pro_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function yule_pro_posted_on() {
	$options = yule_pro_get_theme_options();
	// Get the author name; wrap it in a link.
	$byline = sprintf(
		/* translators: %s: post author */
		__( 'by %s', 'yule-pro' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a></span>'
	);

	if ( yule_pro_archive_meta_option( 'hide_category' ) && yule_pro_single_meta_option( 'single_post_hide_category' ) ) :
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( ' ' );
		if ( $categories_list && yule_pro_categorized_blog() ) {
			printf( '<span class="cat-links"><span class="screen-reader-text">' . esc_html__( 'Posted in %1$s%2$s', 'yule-pro' ) . '</span>', '</span>', $categories_list ); // WPCS: XSS OK.
		}
	endif;

	if ( is_single() && yule_pro_single_meta_option( 'single_post_hide_date' ) ) :
		// Finally, let's write all of this to the page.
		echo '<span class="posted-on">' . yule_pro_time_link() . '</span>';
	endif;

	if ( is_single() && yule_pro_single_meta_option( 'single_post_hide_author' ) ) {
		echo '<span class="byline"> ' . $byline . '</span>';
	}
}
endif;


if ( ! function_exists( 'yule_pro_time_link' ) ) :
/**
 * Gets a nicely formatted string for the published date.
 */
function yule_pro_time_link() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		get_the_date( DATE_W3C ),
		get_the_date(),
		get_the_modified_date( DATE_W3C ),
		get_the_modified_date()
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	return sprintf(
		/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'yule-pro' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
}
endif;

if ( ! function_exists( 'yule_pro_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function yule_pro_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {

			if ( ! is_single() && yule_pro_archive_meta_option( 'hide_date' ) ) :
				// Finally, let's write all of this to the page.
				echo '<span class="posted-on">' . yule_pro_time_link() . '</span>';
			endif;

			if ( is_single() && yule_pro_single_meta_option( 'single_post_hide_tags' ) ) :
				/* translators: used between list items, there is a space after the comma */
				$tags_list = get_the_tag_list( '' );
				if ( $tags_list ) {
					printf( '<span class="tags-links"><span class="screen-reader-text">' . esc_html__( 'Tagged %1$s%2$s', 'yule-pro' ) . '</span>', '</span>', $tags_list ); // WPCS: XSS OK.
				}
			endif;
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) && yule_pro_archive_meta_option( 'hide_comments' ) ) {
			echo '<span class="comments-link">';
			/* translators: %s: post title */
			comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'yule-pro' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'yule-pro' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function yule_pro_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'yule_pro_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'yule_pro_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so yule_pro_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so yule_pro_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in yule_pro_categorized_blog.
 */
function yule_pro_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'yule_pro_categories' );
}
add_action( 'edit_category', 'yule_pro_category_transient_flusher' );
add_action( 'save_post',     'yule_pro_category_transient_flusher' );
