<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

get_header(); 

$options  = yule_pro_get_theme_options();
$column = ! empty( $options['archive_col'] ) ? $options['archive_col'] : 'col-3';
?>
	<div id="page-header" class="relative">
	    <div class="wrapper">
	        <header class="page-header">
	        	<h2 class="page-title">
	            	<?php 
					if ( is_home() && ! is_front_page() ) :
						single_post_title(); 
					else :
						echo ! empty( $options['your_latest_posts_title'] ) ? esc_html( $options['your_latest_posts_title'] ) : esc_html__( 'Blog', 'yule-pro' );
					endif;
					?>
				</h2>
	        </header><!-- .page-header -->
	    </div><!-- .wrapper -->
	</div><!--#header-image -->

	<?php  
    /**
	 * yule_pro_add_breadcrumb_action hook
	 *
	 * @hooked yule_pro_add_breadcrumb -  10
	 *
	 */
	do_action( 'yule_pro_add_breadcrumb_action' );
    ?>

	<div id="inner-content-wrapper" class="page-section">
        <div class="wrapper">
			<div id="primary" class="content-area">
				<main id="main" class="site-main" role="main">
					<div class="posts-wrapper blog-posts <?php echo esc_attr( $column ); ?>">
						<?php
						if ( have_posts() ) : ?>

							<?php
							/* Start the Loop */
							while ( have_posts() ) : the_post();

								/*
								 * Include the Post-Format-specific template for the content.
								 * If you want to override this in a child theme, then include a file
								 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
								 */
								get_template_part( 'template-parts/content', get_post_format() );

							endwhile;

						else :

							get_template_part( 'template-parts/content', 'none' );

						endif; 
						?>
					</div> <!-- #post-wrapper -->
					<?php  
					/**
					* Hook - yule_pro_action_pagination.
					*
					* @hooked yule_pro_pagination 
					*/
					do_action( 'yule_pro_action_pagination' ); 

					/**
					* Hook - yule_pro_infinite_loader_spinner_action.
					*
					* @hooked yule_pro_infinite_loader_spinner 
					*/
					do_action( 'yule_pro_infinite_loader_spinner_action' );
					?>
				</main><!-- #main -->
			</div><!-- #primary -->
			<?php  
			if ( yule_pro_is_sidebar_enable() ) {
				get_sidebar();
			}
			?>
		</div><!-- .wrapper -->
    </div><!-- #inner-content-wrapper-->

<?php
get_footer();
